@@ -17,7 +17,7 @@ class Definitions:
     BEFORE_CONSUME = "before_consume"
     SUCCESS = "success"
     FAIL = "fail"
-    TIME_MEASURE = "time_measure"
+    HISTOGRAM_MEASURE = "histogram_measure"
     CONNECTION_FAIL = "connection_fail"
 
     def __init__(
@@ -38,18 +38,8 @@ class Definitions:
             namespace=self.NAMESPACE,
             unit=self.MESSAGE_UNITS,
         )
-        self._prepare_on_complete(
-            self.SUCCESS,
-            namespace=self.NAMESPACE,
-            unit=self.MESSAGE_UNITS,
-        )
-        self._prepare_on_complete(
-            self.FAIL,
-            namespace=self.NAMESPACE,
-            unit=self.MESSAGE_UNITS,
-        )
-        self._prepare_time_measure(
-            self.TIME_MEASURE,
+        self._prepare_histogram_measure(
+            self.HISTOGRAM_MEASURE,
             namespace=self.NAMESPACE,
             unit=self.TIME_UNITS,
         )
@@ -60,7 +50,7 @@ class Definitions:
         )
 
     def _prepare_before_consume(
-            self, name: str, namespace: str = "", unit: str = ""):
+            self, name: str, namespace: str, unit: str):
 
         self.__metrics[name] = Counter(
                 name="received_number_before_consume",
@@ -71,26 +61,13 @@ class Definitions:
                 registry=self.__registry
             )
 
-    def _prepare_on_complete(
-            self, state: str, namespace: str = "", unit: str = ""):
-
-        self.__metrics[state] = Counter(
-                name=f"consumed_number_on_{state}",
-                documentation=(f"Messages that worker consumed with {state}"
-                               " from queue(s)"),
-                labelnames=self.__labelkeys + ["state", "error"],
-                namespace=namespace,
-                unit=unit,
-                registry=self.__registry
-            )
-
-    def _prepare_time_measure(
-            self, name: str, namespace: str = "", unit: str = ""):
+    def _prepare_histogram_measure(
+            self, name: str, namespace: str, unit: str):
 
         self.__metrics[name] = Histogram(
-                name="time_spent_processing_message",
-                documentation=("Time spent when function was "
-                               "processing a message"),
+                name="processing_message",
+                documentation=("Histogram for time and counter "
+                               "when function was processing a message"),
                 buckets=self.__time_buckets,
                 labelnames=self.__labelkeys + ["state", "error"],
                 namespace=namespace,
@@ -103,7 +80,7 @@ class Definitions:
 
         self.__metrics[state] = Counter(
                 name="connection_fail",
-                documentation=("Number of times barterdude failed "
+                documentation=("Number of times failed "
                                "to connect to the AMQP broker"),
                 labelnames=self.__labelkeys,
                 namespace=namespace,
